@@ -36,11 +36,18 @@ from .fields import SubjectAltNameField
 from .fields import SubjectField
 from .models import Certificate
 from .models import CertificateAuthority
+from .models import X509CertMixin
 from .utils import EXTENDED_KEY_USAGE_DESC
 from .utils import KEY_USAGE_DESC
 from .utils import parse_general_name
 from .widgets import ProfileWidget
 
+if typing.TYPE_CHECKING:
+    CertificateModelForm = forms.ModelForm[Certificate]
+    X509CertMixinModelForm = forms.ModelForm[X509CertMixin]
+else:
+    CertificateModelForm = X509CertMixinModelForm = forms.ModelForm
+
 
 def _initial_expires() -> datetime:
     return datetime.today() + ca_settings.CA_DEFAULT_EXPIRES
@@ -50,7 +57,7 @@ def _profile_choices() -> typing.Iterable[typing.Tuple[str, str]]:
     return sorted([(p, p) for p in ca_settings.CA_PROFILES], key=lambda e: e[0])
 
 
-class X509CertMixinAdminForm(forms.ModelForm):
+class X509CertMixinAdminForm(X509CertMixinModelForm):
     """Admin form to add a dynamic help text to the ``pub`` field.
 
     The help_text is set by adding a value to the help_texts dictionary of the models Meta class. We use this
@@ -73,9 +80,9 @@ class X509CertMixinAdminForm(forms.ModelForm):
             # help_texts is always set since we have a Meta class, but keeping this here as a precaution.
             meta.help_texts = {}
 
-        info = self.instance._meta.app_label, self.instance._meta.model_name
-        url = reverse("admin:%s_%s_download" % info, kwargs={"pk": self.instance.pk})
-        bundle_url = reverse("admin:%s_%s_download_bundle" % info, kwargs={"pk": self.instance.pk})
+        info = f"{self.instance._meta.app_label}_{self.instance._meta.model_name}"
+        url = reverse(f"admin:{info}_download", kwargs={"pk": self.instance.pk})
+        bundle_url = reverse(f"admin:{info}_download_bundle", kwargs={"pk": self.instance.pk})
         meta.help_texts["pub_pem"] = _(
             'Download: <a href="%s?format=PEM">as PEM</a> | <a href="%s?format=DER">as DER</a><br />'
             'Certificate bundle: <a href="%s?format=PEM">as PEM</a>'
@@ -91,7 +98,7 @@ on Wikipedia."""
         }
 
 
-class CreateCertificateBaseForm(forms.ModelForm):
+class CreateCertificateBaseForm(CertificateModelForm):
     """Base class for forms that create a certificate.
 
     This is used by forms for creating a new certificate and resigning an existing one."""
@@ -231,7 +238,7 @@ class ResignCertificateForm(CreateCertificateBaseForm):
     """Admin form for resigning an existing certificate."""
 
 
-class RevokeCertificateForm(forms.ModelForm):
+class RevokeCertificateForm(CertificateModelForm):
     """Admin form for revoking a certificate."""
 
     class Media:
