@@ -32,6 +32,7 @@ from cryptography.hazmat.primitives.hashes import HashAlgorithm
 
 from . import ca_settings
 from .deprecation import RemovedInDjangoCA120Warning
+from .deprecation import RemovedInDjangoCA121Warning
 from .extensions import KEY_TO_EXTENSION
 from .extensions import AuthorityInformationAccess
 from .extensions import AuthorityKeyIdentifier
@@ -65,7 +66,7 @@ class Profile:
     class can be used to create a signed certificate based on the given CA::
 
         >>> Profile('example', subject='/C=AT', extensions={'ocsp_no_check': {}})
-        <Profile: 'example'>
+        <Profile: example>
     """
 
     # pylint: disable=too-many-instance-attributes
@@ -103,10 +104,12 @@ class Profile:
         else:
             self.subject = Subject(ca_settings.CA_DEFAULT_SUBJECT)
 
+        if issuer_name is not None:
+            warnings.warn("issuer_name profile parameter is deprecated", category=RemovedInDjangoCA121Warning)
+
         self.algorithm = parse_hash_algorithm(algorithm)
         self.cn_in_san = cn_in_san
         self.expires = expires or ca_settings.CA_DEFAULT_EXPIRES
-        self.issuer_name = issuer_name
         self.add_crl_url = add_crl_url
         self.add_issuer_url = add_issuer_url
         self.add_ocsp_url = add_ocsp_url
@@ -137,7 +140,6 @@ class Profile:
             and self.extensions == o.extensions
             and self.cn_in_san == o.cn_in_san
             and self.expires == o.expires
-            and self.issuer_name == o.issuer_name
             and self.add_crl_url == o.add_crl_url
             and self.add_issuer_url == o.add_issuer_url
             and self.add_ocsp_url == o.add_ocsp_url
@@ -156,7 +158,7 @@ class Profile:
         return KEY_TO_EXTENSION[key](value)
 
     def __repr__(self) -> str:
-        return "<Profile: %r>" % self.name
+        return f"<Profile: {self.name}>"
 
     def __str__(self) -> str:
         return repr(self)
@@ -284,7 +286,7 @@ class Profile:
             for key in {k for k, v in extensions.items() if v is None and k in cert_extensions}:
                 del cert_extensions[key]
 
-        issuer_name = self._update_from_ca(
+        self._update_from_ca(
             ca,
             cert_extensions,
             add_crl_url=add_crl_url,
@@ -335,7 +337,7 @@ class Profile:
         public_key = csr.public_key()
         builder = get_cert_builder(expires)
         builder = builder.public_key(public_key)
-        builder = builder.issuer_name(issuer_name)
+        builder = builder.issuer_name(ca.pub.loaded.subject)
         builder = builder.subject_name(cert_subject.name)
 
         for _key, extension in cert_extensions.items():
@@ -376,7 +378,7 @@ class Profile:
         add_ocsp_url: bool,
         add_issuer_url: bool,
         add_issuer_alternative_name: bool,
-    ) -> x509.Name:
+    ) -> None:
         """Update data from the given CA.
 
         * Sets the AuthorityKeyIdentifier extension
@@ -391,7 +393,7 @@ class Profile:
             crldp = extensions.setdefault(CRLDistributionPoints.key, CRLDistributionPoints())
             if not isinstance(crldp, CRLDistributionPoints):
                 raise ValueError(
-                    "extensions[%s] is not of type CRLDistributionPoints" % CRLDistributionPoints.key
+                    f"extensions[{CRLDistributionPoints.key}] is not of type CRLDistributionPoints"
                 )
             crldp.append({"full_name": [url.strip() for url in ca.crl_url.split()]})
 
@@ -399,8 +401,7 @@ class Profile:
             aia = extensions.setdefault(AuthorityInformationAccess.key, AuthorityInformationAccess())
             if not isinstance(aia, AuthorityInformationAccess):
                 raise ValueError(
-                    "extensions[%s] is not of type AuthorityInformationAccess"
-                    % AuthorityInformationAccess.key
+                    f"extensions[{AuthorityInformationAccess.key}] is not of type AuthorityInformationAccess"
                 )
             aia.ocsp.append(parse_general_name(ca.ocsp_url))
 
@@ -408,8 +409,7 @@ class Profile:
             aia = extensions.setdefault(AuthorityInformationAccess.key, AuthorityInformationAccess())
             if not isinstance(aia, AuthorityInformationAccess):
                 raise ValueError(
-                    "extensions[%s] is not of type AuthorityInformationAccess"
-                    % AuthorityInformationAccess.key
+                    f"extensions[{AuthorityInformationAccess.key}] is not of type AuthorityInformationAccess"
                 )
             aia.issuers.append(parse_general_name(ca.issuer_url))
 
@@ -417,17 +417,12 @@ class Profile:
             ian = extensions.get(IssuerAlternativeName.key, IssuerAlternativeName())
             if not isinstance(ian, IssuerAlternativeName):
                 raise ValueError(
-                    "extensions[%s] is not of type IssuerAlternativeName" % IssuerAlternativeName.key
+                    f"extensions[{IssuerAlternativeName.key}] is not of type IssuerAlternativeName"
                 )
 
             ian.extend(shlex_split(ca.issuer_alt_name, ","))
             extensions[IssuerAlternativeName.key] = ian
 
-        if self.issuer_name:
-            return self.issuer_name.name
-
-        return ca.pub.loaded.subject
-
     def _update_san_from_cn(
         self,
         cn_in_san: bool,
@@ -439,7 +434,7 @@ class Profile:
                 common_name = parse_general_name(cast(str, subject["CN"]))
             except ValueError as e:
                 raise ValueError(
-                    "%s: Could not parse CommonName as subjectAlternativeName." % subject["CN"]
+                    f"{subject['CN']}: Could not parse CommonName as subjectAlternativeName."
                 ) from e
 
             extensions.setdefault(SubjectAlternativeName.key, SubjectAlternativeName())
@@ -512,7 +507,7 @@ class DefaultProfileProxy:
         return profiles[ca_settings.CA_DEFAULT_PROFILE] == other
 
     def __repr__(self) -> str:
-        return "<DefaultProfile: %r>" % self.name
+        return f"<DefaultProfile: {self.name}>"
 
     def __str__(self) -> str:
         return repr(self)
