@@ -29,7 +29,20 @@ from .acme.constants import Status
 from .typehints import Protocol
 from .utils import sanitize_serial
 
-if TYPE_CHECKING:
+if not TYPE_CHECKING:
+    # Inverting TYPE_CHECKING check here to make pylint==2.9.3 happy:
+    #   https://github.com/PyCQA/pylint/issues/4697
+    AcmeAccountQuerySetBase = (
+        AcmeAuthorizationQuerySetBase
+    ) = (
+        AcmeCertificateQuerySetBase
+    ) = (
+        AcmeChallengeQuerySetBase
+    ) = AcmeOrderQuerySetBase = CertificateQuerySetBase = CertificateAuthorityQuerySetBase = models.QuerySet
+
+    QuerySetTypeVar = TypeVar("QuerySetTypeVar", bound=models.QuerySet)
+    X509CertMixinTypeVar = TypeVar("X509CertMixinTypeVar")
+else:  # pragma: no cover  # only used for type checking
     from .models import AcmeAccount
     from .models import AcmeAuthorization
     from .models import AcmeCertificate
@@ -49,17 +62,6 @@ if TYPE_CHECKING:
 
     QuerySetTypeVar = TypeVar("QuerySetTypeVar", bound=models.QuerySet[X509CertMixin])
     X509CertMixinTypeVar = TypeVar("X509CertMixinTypeVar", bound=X509CertMixin)
-else:
-    AcmeAccountQuerySetBase = (
-        AcmeAuthorizationQuerySetBase
-    ) = (
-        AcmeCertificateQuerySetBase
-    ) = (
-        AcmeChallengeQuerySetBase
-    ) = AcmeOrderQuerySetBase = CertificateQuerySetBase = CertificateAuthorityQuerySetBase = models.QuerySet
-
-    QuerySetTypeVar = TypeVar("QuerySetTypeVar", bound=models.QuerySet)
-    X509CertMixinTypeVar = TypeVar("X509CertMixinTypeVar")
 
 
 class QuerySetProtocol(
@@ -144,14 +146,14 @@ class CertificateAuthorityQuerySet(DjangoCAMixin["CertificateAuthority"], Certif
                 ca = self.get(serial=ca_settings.CA_DEFAULT_CA)
             except self.model.DoesNotExist:
                 # pylint: disable=raise-missing-from; not useful here
-                raise ImproperlyConfigured("CA_DEFAULT_CA: %s: CA not found." % ca_settings.CA_DEFAULT_CA)
+                raise ImproperlyConfigured(f"CA_DEFAULT_CA: {ca_settings.CA_DEFAULT_CA}: CA not found.")
 
             if ca.enabled is False:
-                raise ImproperlyConfigured("CA_DEFAULT_CA: %s is disabled." % ca_settings.CA_DEFAULT_CA)
+                raise ImproperlyConfigured(f"CA_DEFAULT_CA: {ca_settings.CA_DEFAULT_CA} is disabled.")
             if ca.expires < now:
-                raise ImproperlyConfigured("CA_DEFAULT_CA: %s is expired." % ca_settings.CA_DEFAULT_CA)
+                raise ImproperlyConfigured(f"CA_DEFAULT_CA: {ca_settings.CA_DEFAULT_CA} is expired.")
             if ca.valid_from > now:  # OK, how could this ever happen? ;-)
-                raise ImproperlyConfigured("CA_DEFAULT_CA: %s is not yet valid." % ca_settings.CA_DEFAULT_CA)
+                raise ImproperlyConfigured(f"CA_DEFAULT_CA: {ca_settings.CA_DEFAULT_CA} is not yet valid.")
             return ca
 
         # NOTE: We add the serial to sorting make *sure* we have deterministic behavior. In many cases, users
