@@ -14,13 +14,13 @@
 """Reusable utility functions used throughout django-ca."""
 
 import binascii
-import os
 import re
 import shlex
 import typing
 from collections import abc
 from datetime import datetime
 from datetime import timedelta
+from datetime import timezone
 from ipaddress import ip_address
 from ipaddress import ip_network
 from typing import Any
@@ -35,12 +35,13 @@ from urllib.parse import urlparse
 
 import idna
 
-from asn1crypto.core import OctetString
+import asn1crypto.core
 from cryptography import x509
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.asymmetric import dsa
 from cryptography.hazmat.primitives.asymmetric import ec
+from cryptography.hazmat.primitives.asymmetric import ed25519
 from cryptography.hazmat.primitives.asymmetric import rsa
 from cryptography.hazmat.primitives.serialization import Encoding
 from cryptography.x509.oid import NameOID
@@ -65,13 +66,19 @@ from .typehints import SupportsIndex
 
 # List of possible subject fields, in order
 SUBJECT_FIELDS = [
+    "dnQualifier",
     "C",
+    "postalCode",
     "ST",
     "L",
+    "DC",
     "O",
     "OU",
+    "title",
     "CN",
+    "uid",
     "emailAddress",
+    "serialNumber",
 ]
 
 # Description strings for various X509 extensions, taken from "man x509v3_config".
@@ -102,21 +109,37 @@ SAN_NAME_MAPPINGS = {
     x509.OtherName: "otherName",
 }
 
+# Human readable names come from RFC 4519 except where noted
 #: Map OID objects to IDs used in subject strings
 OID_NAME_MAPPINGS: Dict[x509.ObjectIdentifier, str] = {
-    NameOID.COUNTRY_NAME: "C",
-    NameOID.STATE_OR_PROVINCE_NAME: "ST",
-    NameOID.LOCALITY_NAME: "L",
-    NameOID.ORGANIZATION_NAME: "O",
-    NameOID.ORGANIZATIONAL_UNIT_NAME: "OU",
-    NameOID.COMMON_NAME: "CN",
-    NameOID.EMAIL_ADDRESS: "emailAddress",
-    NameOID.SERIAL_NUMBER: "serialNumber",
-    NameOID.JURISDICTION_COUNTRY_NAME: "jurisdictionCountryName",
-    NameOID.JURISDICTION_STATE_OR_PROVINCE_NAME: "jurisdictionStateOrProvinceName",
     NameOID.BUSINESS_CATEGORY: "businessCategory",
+    NameOID.COMMON_NAME: "CN",
+    NameOID.COUNTRY_NAME: "C",
+    NameOID.DN_QUALIFIER: "dnQualifier",
+    NameOID.DOMAIN_COMPONENT: "DC",  # TODO: RFC 4519 also specifies "domainComponent"
+    NameOID.EMAIL_ADDRESS: "emailAddress",  # not specified in RFC 4519
+    NameOID.GENERATION_QUALIFIER: "generationQualifier",
+    NameOID.GIVEN_NAME: "givenName",
+    NameOID.INN: "inn",  # undocumented
+    NameOID.JURISDICTION_COUNTRY_NAME: "jurisdictionCountryName",
+    NameOID.JURISDICTION_LOCALITY_NAME: "jurisdictionLocalityName",
+    NameOID.JURISDICTION_STATE_OR_PROVINCE_NAME: "jurisdictionStateOrProvinceName",
+    NameOID.LOCALITY_NAME: "L",
+    NameOID.OGRN: "ogrn",  # undocumented
+    NameOID.ORGANIZATIONAL_UNIT_NAME: "OU",
+    NameOID.ORGANIZATION_NAME: "O",
+    NameOID.POSTAL_ADDRESS: "postalAddress",
     NameOID.POSTAL_CODE: "postalCode",
+    NameOID.PSEUDONYM: "pseudonym",  # not specified in RFC 4519
+    NameOID.SERIAL_NUMBER: "serialNumber",
+    NameOID.SNILS: "snils",  # undocumented
+    NameOID.STATE_OR_PROVINCE_NAME: "ST",
     NameOID.STREET_ADDRESS: "streetAddress",
+    NameOID.SURNAME: "sn",
+    NameOID.TITLE: "title",
+    NameOID.UNSTRUCTURED_NAME: "unstructuredName",  # not specified in RFC 4519
+    NameOID.USER_ID: "uid",  # TODO: RFC 4519 also specifies "userid"
+    NameOID.X500_UNIQUE_IDENTIFIER: "x500UniqueIdentifier",
 }
 
 # same, but reversed
@@ -124,6 +147,7 @@ NAME_OID_MAPPINGS = {v: k for k, v in OID_NAME_MAPPINGS.items()}
 
 # Some OIDs can occur multiple times
 MULTIPLE_OIDS = (
+    NameOID.DOMAIN_COMPONENT,
     NameOID.ORGANIZATIONAL_UNIT_NAME,
     NameOID.STREET_ADDRESS,
 )
@@ -131,6 +155,57 @@ MULTIPLE_OIDS = (
 # uppercase values as keys for normalizing case
 NAME_CASE_MAPPINGS = {v.upper(): v for v in OID_NAME_MAPPINGS.values()}
 
+
+#: Mapping of canonical hash algorithm names to the implementing classes
+HASH_ALGORITHM_NAMES: typing.Dict[str, typing.Type[hashes.HashAlgorithm]] = {
+    # NOTE: shake128, shake256, blake2b and blake2s require a digest size, which is not currently supported
+    hashes.SHA1.name: hashes.SHA1,
+    hashes.SHA512_224.name: hashes.SHA512_224,
+    hashes.SHA512_256.name: hashes.SHA512_256,
+    hashes.SHA224.name: hashes.SHA224,
+    hashes.SHA256.name: hashes.SHA256,
+    hashes.SHA384.name: hashes.SHA384,
+    hashes.SHA512.name: hashes.SHA512,
+    hashes.SHA3_224.name: hashes.SHA3_224,
+    hashes.SHA3_256.name: hashes.SHA3_256,
+    hashes.SHA3_384.name: hashes.SHA3_384,
+    hashes.SHA3_512.name: hashes.SHA3_512,
+    # hashes.SHAKE128.name: hashes.SHAKE128,
+    # hashes.SHAKE256.name: hashes.SHAKE256,
+    hashes.MD5.name: hashes.MD5,
+    # hashes.BLAKE2b.name: hashes.BLAKE2b,
+    # hashes.BLAKE2s.name: hashes.BLAKE2s,
+    # NOTE: SM3 is added in cryptography 35.0
+    # hashes.SM3.name: hashes.SM3,
+}
+if hasattr(hashes, "SM3"):  # pragma: cryptography>=35.0 branch
+    # PYLINT NOTE: Remove pylint override once cryptography>=35.0 is used
+    HASH_ALGORITHM_NAMES[hashes.SM3.name] = hashes.SM3  # pylint: disable=no-member  # We check above
+
+#: Mapping of canonical elliptic curve names to the implementing classes
+ELLIPTIC_CURVE_NAMES: typing.Dict[str, typing.Type[ec.EllipticCurve]] = {
+    ec.SECT571R1.name: ec.SECT571R1,
+    ec.SECT409R1.name: ec.SECT409R1,
+    ec.SECT283R1.name: ec.SECT283R1,
+    ec.SECT233R1.name: ec.SECT233R1,
+    ec.SECT163R2.name: ec.SECT163R2,
+    ec.SECT571K1.name: ec.SECT571K1,
+    ec.SECT409K1.name: ec.SECT409K1,
+    ec.SECT283K1.name: ec.SECT283K1,
+    ec.SECT233K1.name: ec.SECT233K1,
+    ec.SECT163K1.name: ec.SECT163K1,
+    ec.SECP521R1.name: ec.SECP521R1,
+    ec.SECP384R1.name: ec.SECP384R1,
+    ec.SECP256R1.name: ec.SECP256R1,
+    ec.SECP256K1.name: ec.SECP256K1,
+    ec.SECP224R1.name: ec.SECP224R1,
+    ec.SECP192R1.name: ec.SECP192R1,
+    ec.BrainpoolP256R1.name: ec.BrainpoolP256R1,
+    ec.BrainpoolP384R1.name: ec.BrainpoolP384R1,
+    ec.BrainpoolP512R1.name: ec.BrainpoolP512R1,
+}
+
+
 try:
     # pylint: disable=unused-import,useless-import-alias
     #         Import alias is for mypy (explicit re-export)
@@ -177,7 +252,7 @@ def encode_url(url: str) -> str:
     parsed = urlparse(url)
     if parsed.hostname and parsed.port:
         hostname = idna.encode(parsed.hostname).decode("utf-8")
-        parsed = parsed._replace(netloc="%s:%s" % (hostname, parsed.port))
+        parsed = parsed._replace(netloc=f"{hostname}:{parsed.port}")
     else:
         parsed = parsed._replace(netloc=idna.encode(parsed.netloc).decode("utf-8"))
     return parsed.geturl()
@@ -198,9 +273,9 @@ def encode_dns(name: str) -> str:
         '*.xn--exmple-cua.com'
     """
     if name.startswith("*."):
-        return "*.%s" % idna.encode(name[2:]).decode("utf-8")
+        return f"*.{idna.encode(name[2:]).decode('utf-8')}"
     if name.startswith("."):
-        return ".%s" % idna.encode(name[1:]).decode("utf-8")
+        return f".{idna.encode(name[1:]).decode('utf-8')}"
     return idna.encode(name).decode("utf-8")
 
 
@@ -219,7 +294,8 @@ def format_name(subject: Union[x509.Name, Iterable[Tuple[str, str]]]) -> str:
     if isinstance(subject, x509.Name):
         subject = [(OID_NAME_MAPPINGS[s.oid], s.value) for s in subject]
 
-    return "/%s" % ("/".join(["%s=%s" % (k, v) for k, v in subject]))
+    values = "/".join([f"{k}={v}" for k, v in subject])
+    return f"/{values}"
 
 
 def format_relative_name(name: Union[x509.RelativeDistinguishedName, Iterable[Tuple[str, str]]]) -> str:
@@ -237,7 +313,8 @@ def format_relative_name(name: Union[x509.RelativeDistinguishedName, Iterable[Tu
     if isinstance(name, x509.RelativeDistinguishedName):
         name = [(OID_NAME_MAPPINGS[s.oid], s.value) for s in name]
 
-    return "/%s" % ("/".join(["%s=%s" % (k, v) for k, v in name]))
+    values = "/".join([f"{k}={v}" for k, v in name])
+    return f"/{values}"
 
 
 def format_general_name(name: x509.GeneralName) -> str:
@@ -254,7 +331,7 @@ def format_general_name(name: x509.GeneralName) -> str:
         value = format_name(name.value)
     else:
         value = name.value
-    return "%s:%s" % (SAN_NAME_MAPPINGS[type(name)], value)
+    return f"{SAN_NAME_MAPPINGS[type(name)]}:{value}"
 
 
 def is_power2(num: int) -> bool:
@@ -298,7 +375,7 @@ def add_colons(value: str, pad: str = "0") -> str:
     """
 
     if len(value) % 2 == 1 and pad:
-        value = "%s%s" % (pad, value)
+        value = f"{pad}{value}"
 
     return ":".join([value[i : i + 2] for i in range(0, len(value), 2)])
 
@@ -349,7 +426,7 @@ def sanitize_serial(value: str) -> str:
     if serial != "0":
         serial = serial.lstrip("0")
     if re.search("[^0-9A-F]", serial):
-        raise ValueError("%s: Serial has invalid characters" % value)
+        raise ValueError(f"{value}: Serial has invalid characters")
     return serial
 
 
@@ -378,7 +455,7 @@ def parse_csr(
     if csr_format == Encoding.DER:
         return x509.load_der_x509_csr(force_bytes(csr), default_backend())
 
-    raise ValueError("Unknown CSR format passed: %s" % csr_format)
+    raise ValueError(f"Unknown CSR format passed: {csr_format}")
 
 
 def parse_name(name: str) -> List[Tuple[str, str]]:
@@ -430,12 +507,12 @@ def parse_name(name: str) -> List[Tuple[str, str]]:
     try:
         items = [(NAME_CASE_MAPPINGS[t[0].upper()], force_str(t[2])) for t in NAME_RE.findall(name)]
     except KeyError as e:
-        raise ValueError("Unknown x509 name field: %s" % e.args[0]) from e
+        raise ValueError(f"Unknown x509 name field: {e.args[0]}") from e
 
     # Check that no OIDs not in MULTIPLE_OIDS occur more then once
     for key, oid in NAME_OID_MAPPINGS.items():
         if sum(1 for t in items if t[0] == key) > 1 and oid not in MULTIPLE_OIDS:
-            raise ValueError('Subject contains multiple "%s" fields' % key)
+            raise ValueError(f'Subject contains multiple "{key}" fields')
 
     return sort_name(items)
 
@@ -488,15 +565,15 @@ def validate_email(addr: str) -> str:
 
     """
     if "@" not in addr:
-        raise ValueError("Invalid email address: %s" % addr)
+        raise ValueError(f"Invalid email address: {addr}")
 
     node, domain = addr.rsplit("@", 1)
     try:
         domain = idna.encode(domain).decode("utf-8")
     except idna.IDNAError as e:
-        raise ValueError("Invalid domain: %s" % domain) from e
+        raise ValueError(f"Invalid domain: {domain}") from e
 
-    return "%s@%s" % (node, domain)
+    return f"{node}@{domain}"
 
 
 def validate_hostname(hostname: str, allow_port: bool = False) -> str:
@@ -528,19 +605,19 @@ def validate_hostname(hostname: str, allow_port: bool = False) -> str:
 
         try:
             port = int(port_str)
-        except ValueError as e:
-            raise ValueError("%s: Port must be an integer" % port_str) from e
+        except ValueError as ex:
+            raise ValueError(f"{port_str}: Port must be an integer") from ex
 
         if port < 1 or port > 65535:
-            raise ValueError("%s: Port must be between 1 and 65535" % port)
+            raise ValueError(f"{port}: Port must be between 1 and 65535")
 
     try:
         encoded: str = idna.encode(hostname).decode("utf-8")
-    except idna.IDNAError as e:
-        raise ValueError("%s: Not a valid hostname" % hostname) from e
+    except idna.IDNAError as ex:
+        raise ValueError(f"{hostname}: Not a valid hostname") from ex
 
     if allow_port is True and port is not None:
-        return "%s:%s" % (encoded, port)
+        return f"{encoded}:{port}"
     return encoded
 
 
@@ -567,11 +644,18 @@ def validate_key_parameters(
     ...
 
 
+@typing.overload
+def validate_key_parameters(
+    key_size: Optional[int], key_type: Literal["EdDSA"], ecc_curve: ParsableKeyCurve = None
+) -> Tuple[None, Literal["EdDSA"], None]:
+    ...
+
+
 def validate_key_parameters(
     key_size: Optional[int] = None,
     key_type: Optional[ParsableKeyType] = "RSA",
     ecc_curve: ParsableKeyCurve = None,
-) -> Tuple[Optional[int], Literal["RSA", "DSA", "ECC"], Optional[ec.EllipticCurve]]:
+) -> Tuple[Optional[int], Literal["RSA", "DSA", "ECC", "EdDSA"], Optional[ec.EllipticCurve]]:
     """Validate parameters for private key generation and return sanitized values.
 
     This function can be used to fail early if invalid parameters are passed, before the private key is
@@ -598,11 +682,13 @@ def validate_key_parameters(
             key_size = ca_settings.CA_DEFAULT_KEY_SIZE
 
         if not is_power2(key_size):
-            raise ValueError("%s: Key size must be a power of two" % key_size)
+            raise ValueError(f"{key_size}: Key size must be a power of two")
         if key_size < ca_settings.CA_MIN_KEY_SIZE:
-            raise ValueError("%s: Key size must be least %s bits" % (key_size, ca_settings.CA_MIN_KEY_SIZE))
+            raise ValueError(f"{key_size}: Key size must be least {ca_settings.CA_MIN_KEY_SIZE} bits")
+    elif key_type == "EdDSA":
+        key_size = ecc_curve = None
     else:
-        raise ValueError("%s: Unknown key type" % key_type)
+        raise ValueError(f"{key_type}: Unknown key type")
 
     return key_size, key_type, ecc_curve
 
@@ -624,8 +710,17 @@ def generate_private_key(
     ...
 
 
+@typing.overload
 def generate_private_key(
-    key_size: Optional[int], key_type: Literal["RSA", "DSA", "ECC"], ecc_curve: Optional[ec.EllipticCurve]
+    key_size: int, key_type: Literal["EdDSA"], ecc_curve: None
+) -> ed25519.Ed25519PrivateKey:
+    ...
+
+
+def generate_private_key(
+    key_size: Optional[int],
+    key_type: Literal["RSA", "DSA", "ECC", "EdDSA"],
+    ecc_curve: Optional[ec.EllipticCurve],
 ) -> PrivateKeyTypes:
     """Generate a private key.
 
@@ -652,10 +747,12 @@ def generate_private_key(
         return dsa.generate_private_key(key_size=key_size, backend=default_backend())
     if key_type == "ECC" and ecc_curve is not None:
         return ec.generate_private_key(ecc_curve, default_backend())
+    if key_type == "EdDSA" and ecc_curve is None and key_size is None:
+        return ed25519.Ed25519PrivateKey.generate()
     if key_type == "RSA" and key_size is not None:
         return rsa.generate_private_key(public_exponent=65537, key_size=key_size, backend=default_backend())
 
-    raise ValueError("%s: Invalid key type." % key_type)
+    raise ValueError(f"{key_type}: Invalid key type.")
 
 
 def parse_general_name(name: ParsableGeneralName) -> x509.GeneralName:
@@ -702,7 +799,7 @@ def parse_general_name(name: ParsableGeneralName) -> x509.GeneralName:
     >>> parse_general_name('rid:2.5.4.3')
     <RegisteredID(value=<ObjectIdentifier(oid=2.5.4.3, name=commonName)>)>
     >>> parse_general_name('otherName:2.5.4.3;UTF8:example.com')
-    <OtherName(type_id=<ObjectIdentifier(oid=2.5.4.3, name=commonName)>, value=b'example.com')>
+    <OtherName(type_id=<ObjectIdentifier(oid=2.5.4.3, name=commonName)>, value=b'\\x0c\\x0bexample.com')>
 
     If you give a prefixed value, this function is less forgiving of any typos and does not catch any
     exceptions:
@@ -719,7 +816,7 @@ def parse_general_name(name: ParsableGeneralName) -> x509.GeneralName:
         return name
     if not isinstance(name, str):
         raise ValueError(
-            "Cannot parse general name %s: Must be of type str (was: %s)." % (name, type(name).__name__)
+            f"Cannot parse general name {name}: Must be of type str (was: {type(name).__name__})."
         )
 
     typ = None
@@ -758,13 +855,13 @@ def parse_general_name(name: ParsableGeneralName) -> x509.GeneralName:
         try:
             return x509.DNSName(encode_dns(name))
         except idna.IDNAError as e:
-            raise ValueError("Could not parse name: %s" % name) from e
+            raise ValueError(f"Could not parse name: {name}") from e
 
     if typ == "uri":
         try:
             return x509.UniformResourceIdentifier(encode_url(name))
         except idna.IDNAError as e:
-            raise ValueError("Could not parse DNS name in URL: %s" % name) from e
+            raise ValueError(f"Could not parse DNS name in URL: {name}") from e
     elif typ == "email":
         return x509.RFC822Name(validate_email(name))  # validate_email already raises ValueError
     elif typ == "ip":
@@ -782,26 +879,59 @@ def parse_general_name(name: ParsableGeneralName) -> x509.GeneralName:
     elif typ == "rid":
         return x509.RegisteredID(x509.ObjectIdentifier(name))
     elif typ == "othername":
-        match = re.match("(.*);(.*):(.*)", name)
+        match = re.match("(.*?);(.*?):(.*)", name)
         if match is not None:
             oid, asn_typ, val = match.groups()
-            if asn_typ == "UTF8":
-                parsed_value = val.encode("utf-8")
-            elif asn_typ == "OctetString":
-                parsed_value = OctetString(bytes(bytearray.fromhex(val))).dump()
-            else:
-                raise ValueError("Unsupported ASN type in otherName: %s" % asn_typ)
 
+            # Get DER representation of the value for x509.OtherName()
+            if asn_typ in ("UTF8", "UTF8String"):
+                parsed_value = asn1crypto.core.UTF8String(val).dump()
+            elif asn_typ in ("UNIV", "UNIVERSALSTRING"):
+                parsed_value = asn1crypto.core.UniversalString(val).dump()
+            elif asn_typ in ("IA5", "IA5STRING"):
+                parsed_value = asn1crypto.core.IA5String(val).dump()
+            elif asn_typ in ("BOOL", "BOOLEAN"):
+                # nconf allows for true, y, yes, false, n and no as valid values
+                if val.lower() in ("true", "y", "yes"):
+                    parsed_value = asn1crypto.core.Boolean(True).dump()
+                elif val.lower() in ("false", "n", "no"):
+                    parsed_value = asn1crypto.core.Boolean(False).dump()
+                else:
+                    raise ValueError(
+                        f"Unsupported {asn_typ} specification for otherName: {val}: Must be TRUE or FALSE"
+                    )
+            elif asn_typ in ("UTC", "UTCTIME"):
+                parsed_datetime = datetime.strptime(val, "%y%m%d%H%M%SZ").replace(tzinfo=timezone.utc)
+                parsed_value = asn1crypto.core.UTCTime(parsed_datetime).dump()
+            elif asn_typ in ("GENTIME", "GENERALIZEDTIME"):
+                parsed_datetime = datetime.strptime(val, "%Y%m%d%H%M%SZ").replace(tzinfo=timezone.utc)
+                parsed_value = asn1crypto.core.GeneralizedTime(parsed_datetime).dump()
+            elif asn_typ == "NULL":
+                if val:
+                    raise ValueError("Invalid NULL specification for otherName: Value must not be present")
+                parsed_value = asn1crypto.core.Null().dump()
+            elif asn_typ in ("INT", "INTEGER"):
+                if val.startswith("0x"):
+                    parsed_value = asn1crypto.core.Integer(int(val, 16)).dump()
+                else:
+                    parsed_value = asn1crypto.core.Integer(int(val)).dump()
+            elif asn_typ == "OctetString":
+                parsed_value = asn1crypto.core.OctetString(bytes(bytearray.fromhex(val))).dump()
+            else:
+                raise ValueError(f"Unsupported ASN type in otherName: {asn_typ}")
+
+            # NOTE: cryptography docs are not really clear on what kind of bytes x509.OtherName() expects, but
+            #       the test suite explicitly use b"derdata" as value, indicating DER encoded data.
             return x509.OtherName(x509.ObjectIdentifier(oid), parsed_value)
 
-        raise ValueError("Incorrect otherName format: %s" % name)
+        raise ValueError(f"Incorrect otherName format: {name}")
     elif typ == "dirname":
         return x509.DirectoryName(x509_name(name))
     else:
         try:
             return x509.DNSName(encode_dns(name))
         except idna.IDNAError as e:
-            raise ValueError("Could not parse DNS name: %s" % name) from e
+            raise ValueError(f"Could not parse DNS name: {name}") from e
 
 
 def parse_hash_algorithm(
@@ -863,13 +993,15 @@ def parse_hash_algorithm(
     if isinstance(value, hashes.HashAlgorithm):
         return value
     if isinstance(value, str):
+        if value in HASH_ALGORITHM_NAMES:
+            return HASH_ALGORITHM_NAMES[value]()
         try:
             algo: Type[hashes.HashAlgorithm] = getattr(hashes, value.strip())
             return algo()
         except AttributeError as e:
-            raise ValueError("Unknown hash algorithm: %s" % value) from e
+            raise ValueError(f"Unknown hash algorithm: {value}") from e
 
-    raise ValueError("Unknown type passed: %s" % type(value).__name__)
+    raise ValueError(f"Unknown type passed: {type(value).__name__}")
 
 
 def parse_encoding(value: Optional[Union[str, Encoding]] = None) -> Encoding:
@@ -898,9 +1030,9 @@ def parse_encoding(value: Optional[Union[str, Encoding]] = None) -> Encoding:
         try:
             return Encoding[value]
         except KeyError as e:
-            raise ValueError("Unknown encoding: %s" % value) from e
+            raise ValueError(f"Unknown encoding: {value}") from e
 
-    raise ValueError("Unknown type passed: %s" % type(value).__name__)
+    raise ValueError(f"Unknown type passed: {type(value).__name__}")
 
 
 def parse_expires(expires: Expires = None) -> datetime:
@@ -967,9 +1099,12 @@ def parse_key_curve(value: ParsableKeyCurve = None) -> ec.EllipticCurve:
     if value is None:
         return ca_settings.CA_DEFAULT_ECC_CURVE
 
+    if value in ELLIPTIC_CURVE_NAMES:
+        return ELLIPTIC_CURVE_NAMES[value]()
+
     curve: Type[ec.EllipticCurve] = getattr(ec, value.strip(), type)
     if not issubclass(curve, ec.EllipticCurve):
-        raise ValueError("%s: Not a known Eliptic Curve" % value)
+        raise ValueError(f"{value}: Not a known Eliptic Curve")
     return curve()
 
 
@@ -1011,10 +1146,6 @@ def read_file(path: str) -> bytes:
     If ``path`` is an absolute path, reads a file from the local file system. For relative paths, read the
     file using the storage backend configured using :ref:`CA_FILE_STORAGE <settings-ca-file-storage>`.
     """
-    if os.path.isabs(path):
-        with open(path, "rb") as abs_stream:
-            return abs_stream.read()
-
     stream = ca_storage.open(path)
 
     try:
@@ -1114,7 +1245,8 @@ class GeneralNameList(List[x509.GeneralName]):
         return list.__iadd__(self, (parse_general_name(v) for v in value))
 
     def __repr__(self) -> str:
-        return "<GeneralNameList: %r>" % [format_general_name(v) for v in self]
+        names = [format_general_name(v) for v in self]
+        return f"<GeneralNameList: {names}>"
 
     @typing.overload
     def __setitem__(self, key: SupportsIndex, value: ParsableGeneralName) -> None:  # pragma: no cover
@@ -1134,7 +1266,7 @@ class GeneralNameList(List[x509.GeneralName]):
             # equivalent to l[0] = 'example.com'
             list.__setitem__(self, key, parse_general_name(value))
         else:
-            raise TypeError("%s/%s: Invalid key/value type." % (key, value))
+            raise TypeError(f"{key}/{value}: Invalid key/value type.")
 
     def append(self, value: ParsableGeneralName) -> None:
         """Equivalent to list.append()."""
@@ -1173,7 +1305,7 @@ def get_crl_cache_key(
     scope: Optional[str] = None,
 ) -> str:
     """Get the cache key for a CRL with the given parameters."""
-    return "crl_%s_%s_%s_%s" % (serial, algorithm.name, encoding.name, scope)
+    return f"crl_{serial}_{algorithm.name}_{encoding.name}_{scope}"
 
 
 # NOTE: get_storage_class is typed to Storage (but really returns the subclass FileSystemStorage).
